==> beets-1.3.16.tgz: lib/python2.7/site-packages/beetsplug/bpm.py <==
# -*- coding: utf-8 -*-
# This file is part of beets.
# Copyright 2015, aroquen
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

"""Determine BPM by pressing a key to the rhythm."""

from __future__ import (division, absolute_import, print_function,
                        unicode_literals)

import time

from beets import ui
from beets.plugins import BeetsPlugin


def bpm(max_strokes):
    """Returns average BPM (possibly of a playing song)
    listening to Enter keystrokes.
    """
    t0 = None
    dt = []
    for i in range(max_strokes):
        # Press enter to the rhythm...
        s = raw_input()
        if s == '':
            t1 = time.time()
            # Only start measuring at the second stroke
            if t0:
                dt.append(t1 - t0)
            t0 = t1
        else:
            break

    # Return average BPM
    # bpm = (max_strokes-1) / sum(dt) * 60
    ave = sum([1.0 / dti * 60 for dti in dt]) / len(dt)
    return ave


class BPMPlugin(BeetsPlugin):

    def __init__(self):
        super(BPMPlugin, self).__init__()
        self.config.add({
            u'max_strokes': 3,
            u'overwrite': True,
        })

    def commands(self):
        cmd = ui.Subcommand('bpm',
                            help='determine bpm of a song by pressing \
                            a key to the rhythm')
        cmd.func = self.command
        return [cmd]

    def command(self, lib, opts, args):
        self.get_bpm(lib.items(ui.decargs(args)))

    def get_bpm(self, items, write=False):
        overwrite = self.config['overwrite'].get(bool)
        if len(items) > 1:
            raise ValueError('Can only get bpm of one song at time')

        item = items[0]
        if item['bpm']:
            self._log.info(u'Found bpm {0}', item['bpm'])
            if not overwrite:
                return

        self._log.info(u'Press Enter {0} times to the rhythm or Ctrl-D '
                       u'to exit', self.config['max_strokes'].get(int))
        new_bpm = bpm(self.config['max_strokes'].get(int))
        item['bpm'] = int(new_bpm)
        if write:
            item.try_write()
        item.store()
        self._log.info(u'Added new bpm {0}', item['bpm'])

==> beets-1.3.19.tgz: lib/python2.7/site-packages/beetsplug/bpm.py <==
# -*- coding: utf-8 -*-
# This file is part of beets.
# Copyright 2016, aroquen
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

"""Determine BPM by pressing a key to the rhythm."""

from __future__ import division, absolute_import, print_function

import time

from beets import ui
from beets.plugins import BeetsPlugin


def bpm(max_strokes):
    """Returns average BPM (possibly of a playing song)
    listening to Enter keystrokes.
    """
    t0 = None
    dt = []
    for i in range(max_strokes):
        # Press enter to the rhythm...
        s = raw_input()
        if s == '':
            t1 = time.time()
            # Only start measuring at the second stroke
            if t0:
                dt.append(t1 - t0)
            t0 = t1
        else:
            break

    # Return average BPM
    # bpm = (max_strokes-1) / sum(dt) * 60
    ave = sum([1.0 / dti * 60 for dti in dt]) / len(dt)
    return ave


class BPMPlugin(BeetsPlugin):

    def __init__(self):
        super(BPMPlugin, self).__init__()
        self.config.add({
            u'max_strokes': 3,
            u'overwrite': True,
        })

    def commands(self):
        cmd = ui.Subcommand('bpm',
                            help=u'determine bpm of a song by pressing '
                            u'a key to the rhythm')
        cmd.func = self.command
        return [cmd]

    def command(self, lib, opts, args):
        self.get_bpm(lib.items(ui.decargs(args)))

    def get_bpm(self, items, write=False):
        overwrite = self.config['overwrite'].get(bool)
        if len(items) > 1:
            raise ValueError(u'Can only get bpm of one song at time')

        item = items[0]
        if item['bpm']:
            self._log.info(u'Found bpm {0}', item['bpm'])
            if not overwrite:
                return

        self._log.info(u'Press Enter {0} times to the rhythm or Ctrl-D '
                       u'to exit', self.config['max_strokes'].get(int))
        new_bpm = bpm(self.config['max_strokes'].get(int))
        item['bpm'] = int(new_bpm)
        if write:
            item.try_write()
        item.store()
        self._log.info(u'Added new bpm {0}', item['bpm'])
